# EduKTM
[![PyPI](https://img.shields.io/pypi/v/EduKTM.svg)](https://pypi.python.org/pypi/EduKTM)
[![Build Status](https://www.travis-ci.org/bigdata-ustc/EduKTM.svg?branch=main)](https://www.travis-ci.org/bigdata-ustc/EduKTM)
[![codecov](https://codecov.io/gh/bigdata-ustc/EduKTM/branch/main/graph/badge.svg?token=B7gscOGQLD)](https://codecov.io/gh/bigdata-ustc/EduKTM)
[![Download](https://img.shields.io/pypi/dm/EduKTM.svg?style=flat)](https://pypi.python.org/pypi/EduKTM)
[![License](https://img.shields.io/github/license/bigdata-ustc/EduKTM)](LICENSE)

The Model Zoo of Knowledge Tracing  Models

## Brief introduction to KTM

## List of models

* [KPT,EKPT](EduKTM/KPT) [[doc]](docs/KPT.md) [[example]](examples/KPT)
* [DKT](EduKTM/DKT) [[doc]](docs/DKT.md) [[example]](examples/DKT)

## Contribute

EduKTM is still under development. More algorithms and features are going to be added and we always welcome contributions to help make EduKTM better. If you would like to contribute, please follow this [guideline](CONTRIBUTE.md).

## Citation

If this repository is helpful for you, please cite our work

```
@misc{bigdata2021eduktm,
  title={EduKTM},
  author={bigdata-ustc},
  publisher = {GitHub},
  journal = {GitHub repository},
  year = {2021},
  howpublished = {\url{https://github.com/bigdata-ustc/EduKTM}},
}
```

## Reference